@@ -658,53 +658,10 @@ static SLang_Intrin_Fun_Type Glib_Opaque_Funcs[] =
 /* }}} */
 
 /* Intrinsic variables {{{ */
-static gulong _G_TYPE_INVALID = G_TYPE_INVALID;
-static gulong _G_TYPE_NONE = G_TYPE_NONE;
-static gulong _G_TYPE_INTERFACE = G_TYPE_INTERFACE;
-static gulong _G_TYPE_CHAR = G_TYPE_CHAR;
-static gulong _G_TYPE_UCHAR = G_TYPE_UCHAR;
-static gulong _G_TYPE_BOOLEAN = G_TYPE_BOOLEAN;
-static gulong _G_TYPE_INT = G_TYPE_INT;
-static gulong _G_TYPE_UINT = G_TYPE_UINT;
-static gulong _G_TYPE_LONG = G_TYPE_LONG;
-static gulong _G_TYPE_ULONG = G_TYPE_ULONG;
-static gulong _G_TYPE_INT64 = G_TYPE_INT64;
-static gulong _G_TYPE_UINT64 = G_TYPE_UINT64;
-static gulong _G_TYPE_ENUM = G_TYPE_ENUM;
-static gulong _G_TYPE_FLAGS = G_TYPE_FLAGS;
-static gulong _G_TYPE_FLOAT = G_TYPE_FLOAT;
-static gulong _G_TYPE_DOUBLE = G_TYPE_DOUBLE;
-static gulong _G_TYPE_STRING = G_TYPE_STRING;
-static gulong _G_TYPE_POINTER = G_TYPE_POINTER;
-static gulong _G_TYPE_BOXED = G_TYPE_BOXED;
-static gulong _G_TYPE_PARAM = G_TYPE_PARAM;
-static gulong _G_TYPE_OBJECT = G_TYPE_OBJECT;
 static unsigned long uldummy;
 
 static SLang_Intrin_Var_Type GType_Intrin_Vars [] =
 {
-  MAKE_VARIABLE("G_TYPE_INVALID",&_G_TYPE_INVALID,UL,1),
-  MAKE_VARIABLE("G_TYPE_NONE",&_G_TYPE_NONE,UL,1),
-  MAKE_VARIABLE("G_TYPE_INTERFACE",&_G_TYPE_INTERFACE,UL,1),
-  MAKE_VARIABLE("G_TYPE_CHAR",&_G_TYPE_CHAR,UL,1),
-  MAKE_VARIABLE("G_TYPE_UCHAR",&_G_TYPE_UCHAR,UL,1),
-  MAKE_VARIABLE("G_TYPE_BOOLEAN",&_G_TYPE_BOOLEAN,UL,1),
-  MAKE_VARIABLE("G_TYPE_INT",&_G_TYPE_INT,UL,1),
-  MAKE_VARIABLE("G_TYPE_UINT",&_G_TYPE_UINT,UL,1),
-  MAKE_VARIABLE("G_TYPE_LONG",&_G_TYPE_LONG,UL,1),
-  MAKE_VARIABLE("G_TYPE_ULONG",&_G_TYPE_ULONG,UL,1),
-  MAKE_VARIABLE("G_TYPE_INT64",&_G_TYPE_INT64,UL,1),
-  MAKE_VARIABLE("G_TYPE_UINT64",&_G_TYPE_UINT64,UL,1),
-  MAKE_VARIABLE("G_TYPE_ENUM",&_G_TYPE_ENUM,UL,1),
-  MAKE_VARIABLE("G_TYPE_FLAGS",&_G_TYPE_FLAGS,UL,1),
-  MAKE_VARIABLE("G_TYPE_FLOAT",&_G_TYPE_FLOAT,UL,1),
-  MAKE_VARIABLE("G_TYPE_DOUBLE",&_G_TYPE_DOUBLE,UL,1),
-  MAKE_VARIABLE("G_TYPE_STRING",&_G_TYPE_STRING,UL,1),
-  MAKE_VARIABLE("G_TYPE_POINTER",&_G_TYPE_POINTER,UL,1),
-  MAKE_VARIABLE("G_TYPE_BOXED",&_G_TYPE_BOXED,UL,1),
-  MAKE_VARIABLE("G_TYPE_PARAM",&_G_TYPE_PARAM,UL,1),
-  MAKE_VARIABLE("G_TYPE_OBJECT",&_G_TYPE_OBJECT,UL,1),
-
   MAKE_VARIABLE("G_TYPE_PARAM_CHAR",&uldummy,UL,1),
   MAKE_VARIABLE("G_TYPE_PARAM_UCHAR",&uldummy,UL,1),
   MAKE_VARIABLE("G_TYPE_PARAM_BOOLEAN",&uldummy,UL,1),
@@ -732,14 +689,12 @@ static SLang_Intrin_Var_Type GType_Intrin_Vars [] =
 
 static int init_sl_glib(SLang_NameSpace_Type *ns)
 {
+   int i = -1;
    patch_ftable(Glib_GObject_Funcs, O, GObject_Type);
    patch_ftable(Glib_Opaque_Funcs, O, GtkOpaque_Type);
 
-   {
-	int i = 21, j = 0;
-	while (GType_Intrin_Vars[i].name != NULL)
-		GType_Intrin_Vars[i++].addr = &g_param_spec_types[j++];
-   }
+   while (GType_Intrin_Vars[++i].name != NULL)
+	GType_Intrin_Vars[i].addr = &g_param_spec_types[i];
 
    if (-1 == SLns_add_intrin_var_table (ns, GType_Intrin_Vars, NULL))
 	return -1;
